@@ -21,16 +21,20 @@
 #include "dialog_users_list.h"
 #include "dialog_user.h"
 #include "dialog_choose_user.h"
-#include <glom/glom_privs.h>
-#include <glom/libglom/glade_utils.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/privs.h>
+#include <libglom/db_utils.h>
+#include <glom/glade_utils.h>
+#include <glom/utils_ui.h> //For bold_message()).
 //#include <libgnome/gnome-i18n.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+const char* Dialog_UsersList::glade_id("window_users");
+const bool Dialog_UsersList::glade_developer(true);
+
+Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   m_treeview_users(0),
   m_combo_group(0),
@@ -40,17 +44,13 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
   m_button_user_delete(0),
   m_button_user_edit(0)
 {
-  refGlade->get_widget_derived("combobox_group", m_combo_group);
+  builder->get_widget_derived("combobox_group", m_combo_group);
   m_combo_group->signal_changed().connect(sigc::mem_fun(*this, &Dialog_UsersList::on_combo_group_changed));
 
 
-  refGlade->get_widget("treeview_users", m_treeview_users);
+  builder->get_widget("treeview_users", m_treeview_users);
   if(m_treeview_users)
   {
-    m_treeview_users->set_reorderable();
-    m_treeview_users->enable_model_drag_source();
-    m_treeview_users->enable_model_drag_dest();
-
     Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
     if(refSelection)
     {
@@ -65,23 +65,23 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
 
 
     // Append the View columns:
-    m_treeview_users->append_column(_("User"), m_model_columns_users.m_col_name);
+    m_treeview_users->append_column(C_("Users List", "User"), m_model_columns_users.m_col_name);
   }
 
 
-  refGlade->get_widget("button_delete", m_button_user_delete);
+  builder->get_widget("button_delete", m_button_user_delete);
   m_button_user_delete->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_button_user_delete) );
 
-  refGlade->get_widget("button_add", m_button_user_add);
+  builder->get_widget("button_add", m_button_user_add);
   m_button_user_add->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_button_user_add) );
 
-  refGlade->get_widget("button_remove", m_button_user_remove);
+  builder->get_widget("button_remove", m_button_user_remove);
   m_button_user_remove->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_button_user_remove) );
 
-  refGlade->get_widget("button_new", m_button_user_new);
+  builder->get_widget("button_new", m_button_user_new);
   m_button_user_new->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_button_user_new) );
 
-  refGlade->get_widget("button_edit", m_button_user_edit);
+  builder->get_widget("button_edit", m_button_user_edit);
   m_button_user_edit->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_button_user_edit) );
 
   enable_buttons();
@@ -133,8 +133,7 @@ void Dialog_UsersList::on_button_user_remove()
         const Glib::ustring user = row[m_model_columns_users.m_col_name];
         if(!user.empty())
         {
-          Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" DROP USER \"" + user + "\"";
-          query_execute(strQuery, this);
+          remove_user_from_group(user, m_combo_group->get_active_text());
 
           fill_list();
         }
@@ -161,18 +160,16 @@ void Dialog_UsersList::on_button_user_delete()
         const Glib::ustring user = row[m_model_columns_users.m_col_name];
         if(!user.empty())
         {
-          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete User")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
+          Gtk::MessageDialog dialog(Utils::bold_message(_("Delete User")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
           dialog.set_secondary_text(_("Are your sure that you wish to delete this user?"));
           dialog.set_transient_for(*this);
 
-          int response = dialog.run();
+          const int response = dialog.run();
           dialog.hide();
 
           if(response == Gtk::RESPONSE_OK)
           {
-            Glib::ustring strQuery = "DROP USER " + user;
-            query_execute(strQuery, this);
-
+            remove_user(user);
             fill_list();
           }
         }
@@ -186,23 +183,14 @@ void Dialog_UsersList::on_button_user_delete()
 void Dialog_UsersList::on_button_user_add()
 {
   Dialog_ChooseUser* dialog = 0;
-  try
-  {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_user");
-
-    refXml->get_widget_derived("dialog_choose_user", dialog);
-  }
-  catch(const Gnome::Glade::XmlError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
+  Utils::get_glade_widget_derived_with_warning(dialog);
 
   dialog->set_transient_for(*this);
 
   //Fill it with the list of users:
   dialog->set_user_list( Privs::get_database_users() );
 
-  int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_choose_user");
+  const int response = Glom::Utils::dialog_run_with_help(dialog);
 
   const Glib::ustring user = dialog->get_user();
 
@@ -214,16 +202,20 @@ void Dialog_UsersList::on_button_user_add()
   if(!user.empty())
   {
     //Add it to the group:
-    Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER " + user;
-    query_execute(strQuery, this);
+    const Glib::ustring strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER \"" + user + "\"";
+    const bool test = DbUtils::query_execute_string(strQuery);
+    if(!test)
+      std::cerr << "Dialog_UsersList::on_button_user_add(): ALTER GROUP failed." << std::endl;
 
     //Remove any user rights, so that all rights come from the user's presence in the group:
-    Document_Glom::type_listTableInfo table_list = get_document()->get_tables();
+    Document::type_listTableInfo table_list = get_document()->get_tables();
 
-    for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
-      Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON \"" + (*iter)->get_name() + "\" FROM \"" + user + "\"";
-      query_execute(strQuery, this);
+      const Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON \"" + (*iter)->get_name() + "\" FROM \"" + user + "\"";
+      const bool test = DbUtils::query_execute_string(strQuery);
+      if(!test)
+        std::cerr << "Dialog_UsersList::on_button_user_add(): REVOKE failed." << std::endl;
     }
 
     fill_list();
@@ -233,16 +225,7 @@ void Dialog_UsersList::on_button_user_add()
 void Dialog_UsersList::on_button_user_new()
 {
   Dialog_User* dialog = 0;
-  try
-  {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_user");
-
-    refXml->get_widget_derived("dialog_user", dialog);
-  }
-  catch(const Gnome::Glade::XmlError& ex)
-  {
-    std::cerr << ex.what() << std::endl;
-  }
+  Utils::get_glade_widget_derived_with_warning(dialog);
 
   dialog->set_transient_for(*this);
   dialog->m_combo_group->set_sensitive(false); //It is being added to the current group, so don't offer a different group.
@@ -251,7 +234,7 @@ void Dialog_UsersList::on_button_user_new()
   bool keep_trying = true;
   while(keep_trying)
   {
-    response = Glom::Utils::dialog_run_with_help(dialog, "dialog_user");
+    response = Glom::Utils::dialog_run_with_help(dialog);
 
     //Check the password is acceptable:
     if(response == Gtk::RESPONSE_OK)
@@ -272,19 +255,8 @@ void Dialog_UsersList::on_button_user_new()
   if(response != Gtk::RESPONSE_OK)
     return;
 
-
-  if(!user.empty() && !password.empty())
-  {
-    //Create the user:
-    Glib::ustring strQuery = "CREATE USER \"" + user + "\" PASSWORD '" + password + "'" ;
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(strQuery, this);
-
-    //Add it to the group:
-    strQuery = "ALTER GROUP \"" + m_combo_group->get_active_text() + "\" ADD USER \"" + user + "\"";
-    data_model = query_execute(strQuery, this);
-
-    fill_list();
-  }
+  add_user(user, password, m_combo_group->get_active_text() /* group */);
+  fill_list();
 }
 
 void Dialog_UsersList::on_button_user_edit()
@@ -299,16 +271,7 @@ void Dialog_UsersList::on_button_user_edit()
       Gtk::TreeModel::Row row = *iter;
 
       Dialog_User* dialog = 0;
-      try
-      {
-        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_user");
-
-        refXml->get_widget_derived("dialog_user", dialog);
-      }
-      catch(const Gnome::Glade::XmlError& ex)
-      {
-        std::cerr << ex.what() << std::endl;
-      }
+      Utils::get_glade_widget_derived_with_warning(dialog);
 
       dialog->set_transient_for(*this);
 
@@ -317,10 +280,10 @@ void Dialog_UsersList::on_button_user_edit()
       dialog->m_entry_user->set_sensitive(false); //They can edit the password, but not the name. TODO: Allow editing of name?
 
       //Fill groups:
-      dialog->m_combo_group->clear_text();
+      dialog->m_combo_group->clear_items();
 
-      type_vecStrings group_list = Privs::get_database_groups();
-      for(type_vecStrings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+      type_vec_strings group_list = Privs::get_database_groups();
+      for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
       {
          dialog->m_combo_group->append_text(*iter);
       }
@@ -333,7 +296,7 @@ void Dialog_UsersList::on_button_user_edit()
       bool keep_trying = true;
       while(keep_trying)
       {
-        response = Glom::Utils::dialog_run_with_help(dialog, "dialog_user");
+        response = Glom::Utils::dialog_run_with_help(dialog);
 
         //Check the password is acceptable:
         if(response == Gtk::RESPONSE_OK)
@@ -356,13 +319,15 @@ void Dialog_UsersList::on_button_user_edit()
 
       if(!user.empty() && !password.empty())
       {
-        Glib::ustring strQuery = "ALTER USER \"" + user + "\" PASSWORD '" + password + "'" ;
-        Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(strQuery, this);
+        const Glib::ustring strQuery = "ALTER USER \"" + user + "\" PASSWORD '" + password + "'" ; //TODO: Escape the password.
+        const bool test = DbUtils::query_execute_string(strQuery);
+        if(!test)
+          std::cerr << "Dialog_UsersList::on_button_user_edit(): ALTER USER failed." << std::endl;
 
         //Change the password in the current connection, if this is the current user.
-         ConnectionPool* connection_pool = ConnectionPool::get_instance();
-         if(connection_pool->get_user() == user)
-           connection_pool->set_password(password);
+        ConnectionPool* connection_pool = ConnectionPool::get_instance();
+        if(connection_pool->get_user() == user)
+          connection_pool->set_password(password);
 
         fill_list();
       }
@@ -394,8 +359,8 @@ void Dialog_UsersList::fill_list()
   if(m_combo_group)
   {
     const Glib::ustring group_name = m_combo_group->get_active_text();
-    const type_vecStrings user_list = Privs::get_database_users(group_name);
-    for(type_vecStrings::const_iterator iter = user_list.begin(); iter != user_list.end(); ++iter)
+    const type_vec_strings user_list = Privs::get_database_users(group_name);
+    for(type_vec_strings::const_iterator iter = user_list.begin(); iter != user_list.end(); ++iter)
     {
       Gtk::TreeModel::iterator iterTree = m_model_users->append();
       Gtk::TreeModel::Row row = *iterTree;
@@ -408,10 +373,10 @@ void Dialog_UsersList::fill_list()
 void Dialog_UsersList::set_group(const Glib::ustring& group_name)
 {
   //Fill the list of groups:
-  m_combo_group->clear_text();
+  m_combo_group->clear_items();
 
-  type_vecStrings group_list = Privs::get_database_groups();
-  for(type_vecStrings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+  type_vec_strings group_list = Privs::get_database_groups();
+  for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
   {
     m_combo_group->append_text(*iter);
   }
@@ -431,7 +396,7 @@ bool Dialog_UsersList::warn_about_empty_standard_group()
   {
     if(m_model_users->children().size() == 1)
     {
-      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Developer group may not be empty.")), true, Gtk::MESSAGE_WARNING);
+      Gtk::MessageDialog dialog(Utils::bold_message(_("Developer group may not be empty.")), true, Gtk::MESSAGE_WARNING);
       dialog.set_secondary_text(_("The developer group must contain at least one user."));
       dialog.set_transient_for(*this);
       dialog.run();
