@@ -30,6 +30,7 @@
 #include <libgda/gda-blob-op.h> // For gda_blob_op_read_all()
 
 #include <gtkmm/messagedialog.h>
+#include <gtkmm/stock.h>
 
 #include <giomm.h>
 
@@ -282,11 +283,6 @@ Glib::RefPtr<Gdk::Pixbuf> Utils::get_pixbuf_for_gda_value(const Gnome::Gda::Valu
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
         try
         {
-
-          //g_warning("ImageGlom::set_value(): debug: from db: ");
-          //for(int i = 0; i < 10; ++i)
-          //  g_warning("%02X (%c), ", (guint8)puiData[i], (char)puiData[i]);
-
           refPixbufLoader->write(puiData, (glong)buffer_binary_length);
           result = refPixbufLoader->get_pixbuf();
 
@@ -340,7 +336,7 @@ static int get_width_for_text(Gtk::Widget& widget, const Glib::ustring& text)
 
 int Utils::get_suitable_field_width_for_widget(Gtk::Widget& widget, const sharedptr<const LayoutItem_Field>& field_layout, bool or_title)
 {
-  int result = 150;
+  int result = 150; //Suitable default.
 
   const Field::glom_field_type field_type = field_layout->get_glom_type();
 
@@ -394,7 +390,7 @@ int Utils::get_suitable_field_width_for_widget(Gtk::Widget& widget, const shared
   if(!example_text.empty())
   {
     //Get the width required for this string in the current font:
-    result += get_width_for_text(widget, example_text);
+    result = get_width_for_text(widget, example_text);
   }
 
   if(or_title)
@@ -437,4 +433,88 @@ std::string Utils::get_filepath_with_extension(const std::string& filepath, cons
 }
 
 
+//static:
+Glib::RefPtr<Gdk::Pixbuf> Utils::image_scale_keeping_ratio(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, int target_height, int target_width)
+{
+  if( (target_height == 0) || (target_width == 0) )
+    return Glib::RefPtr<Gdk::Pixbuf>(); //This shouldn't happen anyway.
+
+  if(!pixbuf)
+    return pixbuf;
+
+  enum enum_scale_mode
+  {
+    SCALE_WIDTH,
+    SCALE_HEIGHT,
+    SCALE_NONE
+  };
+
+  enum_scale_mode scale_mode = SCALE_NONE; //Start with either the width or height, and scale the other according to the ratio.
+
+  const int pixbuf_height = pixbuf->get_height();
+  const int pixbuf_width = pixbuf->get_width();
+
+  if(pixbuf_height > target_height)
+  {
+    if(pixbuf_width > target_width)
+    {
+      //Both are bigger than the target, so find the biggest one:
+      if(pixbuf_width > pixbuf_height)
+        scale_mode = SCALE_WIDTH;
+      else
+        scale_mode = SCALE_HEIGHT;
+    }
+    else
+    {
+      //Only the height is bigger:
+      scale_mode = SCALE_HEIGHT;
+    }
+  }
+  else if(pixbuf_width > target_width)
+  {
+    //Only the height is bigger:
+    scale_mode = SCALE_WIDTH;
+  }
+
+  if(scale_mode == SCALE_NONE)
+    return pixbuf;
+  else if(scale_mode == SCALE_HEIGHT)
+  {
+    const float ratio = (float)target_height / (float)pixbuf_height; 
+    target_width = (int)((float)pixbuf_width * ratio);
+  }
+  else if(scale_mode == SCALE_WIDTH)
+  {
+    const float ratio = (float)target_width / (float) pixbuf_width;
+    target_height = (int)((float)pixbuf_height * ratio);
+  }
+
+ if( (target_height == 0) || (target_width == 0) )
+ {
+   return Glib::RefPtr<Gdk::Pixbuf>(); //This shouldn't happen anyway. It seems to happen sometimes though, when ratio is very small.
+ }
+
+  return pixbuf->scale_simple(target_width, target_height, Gdk::INTERP_NEAREST);
+}
+
+bool Utils::show_warning_no_records_found(Gtk::Window& transient_for)
+{
+  const Glib::ustring message = _("Your find criteria did not match any records in the table.");
+
+#ifdef GLOM_ENABLE_MAEMO
+  Hildon::Note dialog(Hildon::NOTE_TYPE_CONFIRMATION_BUTTON, transient_for, message);
+#else
+  Gtk::MessageDialog dialog(Utils::bold_message(_("No Records Found")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE);
+  dialog.set_secondary_text(message);
+  dialog.set_transient_for(transient_for);
+#endif
+
+  dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+  dialog.add_button(_("New Find"), Gtk::RESPONSE_OK);
+
+  const bool find_again = (dialog.run() == Gtk::RESPONSE_OK);
+  return find_again;
+}
+
+
 } //namespace Glom
